@@ -3,8 +3,8 @@
  * Copyright (C) 2000-2003, Ximian, Inc.
  */
 
-#ifndef SOUP_MESSAGE_H
-#define SOUP_MESSAGE_H 1
+#ifndef __SOUP_MESSAGE_H__
+#define __SOUP_MESSAGE_H__ 1
 
 #include <libsoup/soup-types.h>
 #include <libsoup/soup-message-body.h>
@@ -137,7 +137,8 @@ typedef enum {
 	SOUP_MESSAGE_CERTIFICATE_TRUSTED      = (1 << 5),
 	SOUP_MESSAGE_NEW_CONNECTION           = (1 << 6),
 	SOUP_MESSAGE_IDEMPOTENT               = (1 << 7),
-	SOUP_MESSAGE_IGNORE_CONNECTION_LIMITS = (1 << 8)
+	SOUP_MESSAGE_IGNORE_CONNECTION_LIMITS = (1 << 8),
+	SOUP_MESSAGE_DO_NOT_USE_AUTH_CACHE    = (1 << 9)
 } SoupMessageFlags;
 
 SOUP_AVAILABLE_IN_2_4
@@ -255,4 +256,4 @@ void soup_message_finished            (SoupMessage *msg);
 
 G_END_DECLS
 
-#endif /*SOUP_MESSAGE_H*/
+#endif /* __SOUP_MESSAGE_H__ */
